;; Generated package description from greenbar.el  -*- no-byte-compile: t -*-
(define-package "greenbar" "1.1.0.20201201.210428" "Mark comint output with \"greenbar\" background" 'nil :url "https://elpa.gnu.org/packages/greenbar.html" :keywords '("faces" "terminals") :authors '(("Michael R. Mauger" . "michael@mauger.com")) :maintainer '("Michael R. Mauger" . "michael@mauger.com"))
